@@ -15,18 +15,17 @@ public:
     virtual ~BrightnessLogic() = default;
 
     /**
-     * This enum defines the different types brightness keys.
+     * This enum defines different types of discrete brightness adjustment actions.
+     * These will usually get triggered by brightness keys or scroll wheel events.
      *
-     * - Increase: Key to increase brightness (Qt::Key_MonBrightnessUp or Qt::Key_KeyboardBrightnessUp)
-     * - Decrease: Key to decrease brightness (Qt::Key_MonBrightnessDown or Qt::Key_KeyboardBrightnessDown)
-     * - Toggle: Key to toggle backlight (Qt::Key_KeyboardBacklightOnOff)
-     * - IncreaseSmall: Key to increase brightness by 1% (Qt::Key_MonBrightnessUp or Qt::Key_KeyboardBrightnessUp + Qt::ShiftModifier)
-     * - DecreaseSmall: Key to decrease brightness by 1% (Qt::Key_MonBrightnessDown or Qt::Key_KeyboardBrightnessDown + Qt::ShiftModifier)
+     * - Increase: Increase brightness by one step (Qt::Key_MonBrightnessUp or Qt::Key_KeyboardBrightnessUp)
+     * - Decrease: Decrease brightness by one step (Qt::Key_MonBrightnessDown or Qt::Key_KeyboardBrightnessDown)
+     * - IncreaseSmall: Increase brightness by a small step such as 1% (Qt::Key_MonBrightnessUp or Qt::Key_KeyboardBrightnessUp + Qt::ShiftModifier)
+     * - DecreaseSmall: Decrease brightness by a small step such as 1% (Qt::Key_MonBrightnessDown or Qt::Key_KeyboardBrightnessDown + Qt::ShiftModifier)
      */
-    enum BrightnessKeyType {
+    enum StepAdjustmentAction {
         Increase,
         Decrease,
-        Toggle,
         IncreaseSmall,
         DecreaseSmall,
     };
@@ -46,8 +45,6 @@ public:
         int valueMin = -1;
         /** The maximum possible brightness value for this device */
         int valueMax = -1;
-        /** The most recent brightness before toggling off */
-        int valueBeforeTogglingOff = -1;
         /** The maximum possible brightness step for this device */
         int steps = -1;
     };
@@ -59,6 +56,19 @@ public:
      */
     void setValue(int value);
 
+    /**
+     * Retrieve the current brightness value, expressed as a ratio from 0.0 to 1.0
+     */
+    double valueAsRatio() const;
+
+    /**
+     * Return the discrete brightness value corresponding to a ratio from 0.0 to 1.0
+     *
+     * @param ratio Brightness value expressed as a ratio, on a scale from 0.0 to 1.0
+     * @return The brightness value for the supplied ratio, clamped to the range from 0 to valueMax
+     */
+    int valueFromRatio(double ratio) const;
+
     /**
      * Sets the minimum and maximum brightness value.
      *
@@ -68,19 +78,12 @@ public:
     void setValueRange(int valueMin, int valueMax);
 
     /**
-     * Sets the last active brightness value.
+     * Calculate new brightness value that should be set by a discrete brightness adjustment action.
      *
-     * @param value Last active brightness value
-     */
-    void setValueBeforeTogglingOff(int valueBeforeTogglingOff);
-
-    /**
-     * Calculate new brightness value that should be set by an action.
-     *
-     * @param type The action type of the key that was pressed.
+     * @param adjustment The adjustment action, defining the step size and direction.
      * @return The brightness value that the action should set, or -1 if nothing should be done
      */
-    int action(BrightnessKeyType type) const;
+    int adjusted(StepAdjustmentAction adjustment) const;
 
     /**
      * Calculates the brightness value of the closest step upwards.
@@ -98,14 +101,6 @@ public:
      */
     int decreased() const;
 
-    /**
-     * Calculates the brightness value of the toggled state.
-     * (Sets the brightness value to either minimum, last active brightness or maximum).
-     *
-     * @return The brightness value that should be set, or -1 if nothing should be done
-     */
-    virtual int toggled() const;
-
     /**
      * Calculates the brightness value of the closest step upwards.
      * (Closest step that is higher than current brightness value).
@@ -130,12 +125,12 @@ public:
     int steps() const;
 
     /**
-     * Retrieve the supplied brightness value expressed as a percentage from 0 to 100
+     * Retrieve the supplied brightness value expressed as a ratio from 0.0 to 1.0
      *
      * @param value Brightness value, from 0 to valueMax
      * @return The brightness percentage for the supplied value
      */
-    float percentage(int value) const;
+    double ratio(int value) const;
 
     /**
      * Retrieve a copy of the current brightness state
